==> jc-1.4.0.tar.gz: soot/jimple/toolkits/pointer/nativemethods/JavaUtilJarJarFileNative.h <==
// public class soot.jimple.toolkits.pointer.nativemethods.JavaUtilJarJarFileNative

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 7a82a075090d2ac5 soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative
// @dep_class adf075d6a4c28634 soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

// header file dependencies
// @dep_header soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

#include "soot/jimple/toolkits/pointer/nativemethods/NativeMethodClass.h"

#ifndef _JC_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative_H_
#define _JC_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$object;
struct _jc_soot_jimple_toolkits_pointer_representations_ReferenceVariable$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$sub_refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$object	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$vmethods	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$vtable	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$vtype	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$method$simulateMethod$16021ad0ff992382(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$method_info$simulateMethod$16021ad0ff992382;

// Static methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$method$java__5futil__5fjar__5fJarFile__5fgetMetaInfoEntryNames$8f99240432c57dda(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);
extern struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$object *_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$method$v$191df86d82ce555f(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$vmethods {
	void	(*simulateMethod$16021ad0ff992382)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vmethods	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$vmethods	soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$refs {
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$sub_refs	soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_refs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$object {
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$vtype _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/pointer/nativemethods/JavaUtilJarJarFileNative.h <==
// public class soot.jimple.toolkits.pointer.nativemethods.JavaUtilJarJarFileNative

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7a82a075090d2ac5 soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative
// @dep_class adf075d6a4c28634 soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

// header file dependencies
// @dep_header soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

#include "soot/jimple/toolkits/pointer/nativemethods/NativeMethodClass.h"

#ifndef _JC_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative_H_
#define _JC_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$object;
struct _jc_soot_jimple_toolkits_pointer_representations_ReferenceVariable$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$sub_refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$object	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$vmethods	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$vtable	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$vtype	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$method$simulateMethod$16021ad0ff992382(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$method_info$simulateMethod$16021ad0ff992382;

// Static methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$method$java__5futil__5fjar__5fJarFile__5fgetMetaInfoEntryNames$8f99240432c57dda(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$object *_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$method$v$191df86d82ce555f(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$vmethods {
	void	(*simulateMethod$16021ad0ff992382)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vmethods	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$vmethods	soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$refs {
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$sub_refs	soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_refs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$object {
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$vtype _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_nativemethods_JavaUtilJarJarFileNative_H_ */
